################################################################################
#
# QBank Charge Function
#
# You will need to modify this file to meet site charge requirements
#
################################################################################
#use QBank::Result; 
sub charge {

################################################################################
# This first section uses the default simplest case algorithm
# This algorithm charges strictly for processor-seconds used on the system(s).
# It would be appropriate to uncomment this section if you simply want to
# allocate and regulate the consumption of processors across the system(s).
################################################################################

my $charge=$ARGS{PROCS}*$ARGS{WCTIME}; # simplest case

################################################################################
# This second section uses static charge multipliers to support more complex
# charging algorithms such as class, CPU consumption rates, memory used or QOS.
# It would be appropriate to uncomment these sections if you are only managing
# one system per QBank database or your charge rates are the same across all
# machines and you don't need to dynamically change the charge rates.
################################################################################

#my $charge=0; # Initialize charge to zero (always uncomment this line)

# Uncomment this section for processor-second based accounting (almost always).
# Charges for Processor, Memory and Disk (if used) should be added with their
# respective weighting factors and multiplied by wallclock time in seconds.
# $PROCRATE=1;
#my $charge=$ARGS{PROCS}*$PROCRATE;

# Uncomment the section below if you want to charge by CPU consumption rate.
# This may be useful on large SMP systems where jobs share the CPUs
# and you need to account for the average percentage of the processors consumed.
# *** Note the distinction between PROCRATE and PROCCRATE ***
#if (defined $ARGS{PROCCRATE})
#	{
#	if ($ARGS{PROCCRATE}>=0 && $ARGS{PROCCRATE}<=1)
#		{
#		$charge*=$ARGS{PROCCRATE});
#		}
#	else
#		{
#		return QBank::Result::failure("Invalid PROCCRATE $ARGS{PROCCRATE}: must be between 0 and 1 inclusive)");
#		}
#	}

# Uncomment and modify the section below if you want to charge by MEMORY used.
# The example is adjusted to charge based on MegaBytes of Memory.
# $MEMRATE=2;
#if (defined $ARGS{MEMORY})
#	{
#	$charge+=$ARGS{MEMORY}/1048576*$MEMRATE;
#	}

# Uncomment and modify the section below if you want to charge by DISK used.
# The example is adjusted to charge based on MegaBytes of Disk.
# $DISKRATE=0.5;
#if (defined $ARGS{DISK})
#	{
#	$charge+=$ARGS{DISK}/1048576*$DISKRATE;
#	}

# Uncomment this line for resource-time based accounting (almost always)
#$charge*=$ARGS{WCTIME}; # Multiply additive charges by WallClock Time

# Uncomment the section below if you want to charge by Quality of Service.
# You will need to modify the QOS associative array below for your needs.
#%QOSCHARGE = ( 0 => 0, 1 => 1, 2 => 0.5, 3 => 1.5, 4 => 2 );
#if (defined $ARGS{QOS})
#	{
#	if (defined $QOSCHARGE{$ARGS{QOS}})
#		{
#		$charge*=$QOSCHARGE{$ARGS{QOS}};
#		}
#	else
#		{
#		return QBank::Result::failure("Invalid QOS $ARGS{QOS}");
#		}
#	}

# Uncomment and modify the section below if you want to charge by NodeType
#%NODECHARGE = ( DEFAULT => 1 , P2SC => 1.5 , SMP => 2, SGI => 0.8 );
#if (defined $ARGS{NODETYPE})
#	{
#	if (defined $NODECHARGE{$ARGS{NODETYPE}})
#		{
#		$charge*=$NODECHARGE{$ARGS{NODETYPE}};
#		}
#	else
#		{
#		return QBank::Result::failure("Invalid NODETYPE $ARGS{NODETYPE}");
#		}
#	}

# Uncomment and modify the section below if you want to charge by Class
#%CLASSCHARGE = ( interactive => 0.5 , batch => 1 , premium => 2 );
#if (defined $ARGS{CLASS})
#	{
#	if (defined $CLASSCHARGE{$ARGS{CLASS}})
#		{
#		$charge*=$CLASSCHARGE{$ARGS{CLASS}};
#		}
#	else
#		{
#		return QBank::Result::failure("Invalid CLASS $ARGS{CLASS}");
#		}
#	}

# Uncomment and modify the section below if you want to charge by Machine
#%MACHCHARGE = ( BIGIRON => 1 , BIGBLUE => 1.5 , CRAYFISH => 2 );
#if (defined $ARGS{MACHINE})
#	{
#	if (defined $MACHCHARGE{$ARGS{MACHINE}})
#		{
#		$charge*=$MACHCHARGE{$ARGS{MACHINE}};
#		}
#	else
#		{
#		return QBank::Result::failure("Invalid MACHINE $ARGS{MACHINE}");
#		}
#	}

################################################################################
# This third section uses the dynamic ChargeRate database tables
# It would be appropriate to uncomment these sections instead of those above
# if you are managing multiple systems per QBank database and have charge rates
# which differ per machine, or if you wish to implement dynamic charge rates.
################################################################################

#my $charge=0; # Initialize charge to zero

# Uncomment and modify this section if you want to charge by amount of CPU used
#if (defined $ARGS{PROCS})
#	{
#	if (defined $ARGS{MACHINE} && QBank::ChargeRate->exists({ MACHINE => $ARGS{MACHINE}, TYPE => SIMPLE, NAME => PROCS }))
#		{
#		$charge+=$ARGS{PROCS}*(QBank::ChargeRate->get({ MACHINE => $ARGS{MACHINE}, TYPE => SIMPLE, NAME => PROCS, SHOW => chargerate }));
#		}
#	elsif (QBank::ChargeRate->exists({ MACHINE => DEFAULT, TYPE => SIMPLE, NAME => PROCS }))
#		{
#		$charge+=$ARGS{PROCS}*(QBank::ChargeRate->get({ MACHINE => DEFAULT, TYPE => SIMPLE, NAME => PROCS, SHOW => chargerate }));
#		}
#	}

# Uncomment and modify this section if you want to charge by amount of memory used
#if (defined $ARGS{MEMORY})
#	{
#	if (defined $ARGS{MACHINE} && QBank::ChargeRate->exists({ MACHINE => $ARGS{MACHINE}, TYPE => SIMPLE, NAME => MEMORY }))
#		{
#		$charge+=$ARGS{MEMORY}/1048576*(QBank::ChargeRate->get({ MACHINE => $ARGS{MACHINE}, TYPE => SIMPLE, NAME => MEMORY, SHOW => chargerate }));
#		}
#	elsif (QBank::ChargeRate->exists({ MACHINE => DEFAULT, TYPE => SIMPLE, NAME => MEMORY }))
#		{
#		$charge+=$ARGS{MEMORY}/1048576*(QBank::ChargeRate->get({ MACHINE => DEFAULT, TYPE => SIMPLE, NAME => MEMORY, SHOW => chargerate }));
#		}
#	}

# Uncomment and modify this section if you want to charge by amount of disk used
#if (defined $ARGS{DISK})
#	{
#	if (defined $ARGS{MACHINE} && QBank::ChargeRate->exists({ MACHINE => $ARGS{MACHINE}, TYPE => SIMPLE, NAME => DISK }))
#		{
#		$charge+=$ARGS{DISK}/1048576*(QBank::ChargeRate->get({ MACHINE => $ARGS{MACHINE}, TYPE => SIMPLE, NAME => DISK, SHOW => chargerate }));
#		}
#	elsif (QBank::ChargeRate->exists({ MACHINE => DEFAULT, TYPE => SIMPLE, NAME => DISK }))
#		{
#		$charge+=$ARGS{DISK}/1048576*(QBank::ChargeRate->get({ MACHINE => DEFAULT, TYPE => SIMPLE, NAME => DISK, SHOW => chargerate }));
#		}
#	}

# Take all the above additive sections and multiply by WallClock Time
#$charge*=$ARGS{WCTIME};
#
## Uncomment this section if you want to charge based on Quality of Service
#if (defined $ARGS{QOS})
#	{
#	if (defined $ARGS{MACHINE} && QBank::ChargeRate->exists({ MACHINE => $ARGS{MACHINE}, TYPE => QOS, NAME => $ARGS{QOS}}))
#		{
#		$charge*=QBank::ChargeRate->get({ MACHINE => $ARGS{MACHINE}, TYPE => QOS, NAME => $ARGS{QOS}, SHOW => chargerate });
#		}
#	elsif (QBank::ChargeRate->exists({ MACHINE => DEFAULT, TYPE => QOS, NAME => $ARGS{QOS}}))
#		{
#		$charge*=QBank::ChargeRate->get({ MACHINE => DEFAULT, TYPE => QOS, NAME => $ARGS{QOS}, SHOW => chargerate });
#		}
#	}

# Uncomment this section if you want to charge a multiplier based on nodetype
#if (defined $ARGS{NODETYPE})
#	{
#	if (defined $ARGS{MACHINE} && QBank::ChargeRate->exists({ MACHINE => $ARGS{MACHINE}, TYPE => NODE, NAME => $ARGS{NODETYPE}}))
#		{
#		$charge*=QBank::ChargeRate->get({ MACHINE => $ARGS{MACHINE}, TYPE => NODE, NAME => $ARGS{NODETYPE}, SHOW => chargerate });
#		}
#	elsif (QBank::ChargeRate->exists({ MACHINE => DEFAULT, TYPE => NODE, NAME => $ARGS{NODETYPE}}))
#		{
#		$charge*=QBank::ChargeRate->get({ MACHINE => DEFAULT, TYPE => NODE, NAME => $ARGS{NODETYPE}, SHOW => chargerate });
#		}
#	}

# Uncomment this section if you want to charge a multiplier based on the job class
#if (defined $ARGS{CLASS})
#	{
#	if (defined $ARGS{MACHINE} && QBank::ChargeRate->exists({ MACHINE => $ARGS{MACHINE}, TYPE => CLASS, NAME => $ARGS{CLASS}}))
#		{
#		$charge*=QBank::ChargeRate->get({ MACHINE => $ARGS{MACHINE}, TYPE => CLASS, NAME => $ARGS{CLASS}, SHOW => chargerate });
#		}
#	elsif (QBank::ChargeRate->exists({ MACHINE => DEFAULT, TYPE => CLASS, NAME => $ARGS{CLASS}}))
#		{
#		$charge*=QBank::ChargeRate->get({ MACHINE => DEFAULT, TYPE => CLASS, NAME => $ARGS{CLASS}, SHOW => chargerate });
#		}
#	}

# Uncomment this section if you want to charge a multiplier based on the machine the job ran on
#if (defined $ARGS{MACHINE})
#	{
#	if (QBank::ChargeRate->exists({ MACHINE => $ARGS{MACHINE}, TYPE => MACHINE, NAME => $ARGS{MACHINE}}))
#		{
#		$charge*=QBank::ChargeRate->get({ MACHINE => $ARGS{MACHINE}, TYPE => MACHINE, NAME => $ARGS{MACHINE}, SHOW => chargerate });
#		}
#	elsif (QBank::ChargeRate->exists({ MACHINE => DEFAULT, TYPE => MACHINE, NAME => $ARGS{MACHINE}}))
#		{
#		$charge*=QBank::ChargeRate->get({ MACHINE => DEFAULT, TYPE => MACHINE, NAME => $ARGS{MACHINE}, SHOW => chargerate });
#		}
#	}

# Uncomment this section if you want to charge a multiplier based on the time
#if (defined $ARGS{TIME})
#	{
#	if (defined $ARGS{MACHINE} && QBank::ChargeRate->exists({ MACHINE => $ARGS{MACHINE}, TYPE => TIME, NAME => $ARGS{TIME}}))
#		{
#		$charge*=QBank::ChargeRate->get({ MACHINE => $ARGS{MACHINE}, TYPE => TIME, NAME => $ARGS{TIME}, SHOW => chargerate });
#		}
#	elsif (QBank::ChargeRate->exists({ MACHINE => DEFAULT, TYPE => TIME, NAME => $ARGS{TIME}}))
#		{
#		$charge*=QBank::ChargeRate->get({ MACHINE => DEFAULT, TYPE => TIME, NAME => $ARGS{TIME}, SHOW => chargerate });
#		}
#	}

# Returns the integer charge to the calling program
return int($charge);
}

1;
