#!/usr/local/bin/perl
################################################################################
#
# CLIENT
#
################################################################################
#                                                                              #
#                 COPYRIGHT (C) 1994, 1995, 1996, 1997, 1998                   #
#                  Pacific Northwest National Laboratory,                      #
#                       Battelle Memorial Institute.                           #
#                                                                              #
#                          All Rights Reserved                                 #
#                                                                              #
################################################################################
#                                                                              #
#                              DISCLAIMER                                      #
#                                                                              #
#   This material was prepared as an account of work sponsored by an agency    #
#   of the United States Government.  Neither the United States Government     #
#   nor the United States Department of Energy, nor Battelle, nor any of their #
#   employees, MAKES ANY WARRANTY, EXPRESS OR IMPLIED, OR ASSUMES ANY LEGAL    #
#   LIABILITY OR RESPONSIBILITY FOR THE ACCURACY, COMPLETENESS, OR USEFULNESS  #
#   OF ANY INFORMATION, APPARATUS, PRODUCT, SOFTWARE, OR PROCESS DISCLOSED,    #
#   OR REPRESENTS THAT ITS USE WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.      #
#                                                                              #
################################################################################
#                                                                              #
#                              LIMITED USE                                     #
#                                                                              #
#   This software (including any documentation) is being made available to     #
#   you for your internal use only, solely for use in performance of work      #
#   directly for the U.S. Federal Government or work under contracts with      #
#   the U.S. Department of Energy or other U.S. Federal Government agencies.   #
#   This software is a version which has not yet been evaluated and cleared    #
#   for commercialization.  Adherence to this notice may be necessary for the  #
#   author, Battelle Memorial Institute, to successfully assert copyright in   #
#   and commercialize this software.  This software is not intended for        #
#   duplication or distribution to third parties without the permission of     #
#   the Manager of Software Products at Pacific Northwest National Laboratory, #
#   Richland, Washington, 99352.                                               #
#                                                                              #
################################################################################
#                                                                              #
#                              ACKNOWLEDGMENT                                  #
#                                                                              #
#   This software and its documentation were produced with Government support  #
#   under Contract Number DE-AC06-76RLO-1830 awarded by the United States      #
#   Department of Energy.  The Government retains a paid-up non-exclusive,     #
#   irrevocable worldwide license to reproduce, prepare derivative works,      #
#   perform publicly and display publicly by or for the Government, including  #
#   the right to distribute to other Government contractors.                   #
#                                                                              #
################################################################################

# Catch Signals
#$SIG{"INT"} = 'IGNORE';
#$SIG{"HUP"} = 'IGNORE';
#$SIG{"QUIT"} = 'IGNORE';
#$SIG{"ABRT"} = 'IGNORE';
#BEGIN { $SIG{'__WARN__'} = sub { warn $_[0] if $DOWARN } }

use Getopt::Std;
use Socket;
require "${PREFIX}/lib/qbank.ph";

#$DOWARN = 1;
$QAUTH="${PREFIX}/bin/qauth -c";
$AUTH=(getpwuid($<))[0];

################################################################################
#
# subroutine qbank($COMMAND)
#
# Sends command to bank server and returns the parsed result and status
#
################################################################################
sub qbank
{
  my($COMMAND,$REQUEST,@REPLY,$result);
  my($sockaddr,$hostname);
  my($name,$aliases,$proto,$port,$type,$len,$thisaddr);
  my($thisport,$thatport,$response,$result);

  $COMMAND = shift;

  #
  # Establish socket connection
  #
  $sockaddr = 'S n a4 x8';
  chop ($hostname = `hostname`);
  ($name,$aliases,$proto)=getprotobyname('tcp');
  ($name,$aliases,$type,$len,$thisaddr)=gethostbyname($hostname);
  ($name,$aliases,$type,$len,$thataddr)=gethostbyname($BANK_HOST);
  $thisport=pack($sockaddr, &AF_INET,0,$thisaddr);
  $thatport=pack($sockaddr, &AF_INET,$BANK_PORT,$thataddr);
  socket(S, &PF_INET,&SOCK_STREAM,$proto) || die "cannot create socket\n";
  bind(S,$thisport) || die "cannot bind socket\n";
  connect(S,$thatport) || die "cannot connect socket\n";

  select(S); $| = 1;              # Turn on autoflushing
  select(stdout); $| = 1;         # Select STDOUT as default output

  #
  # Build  and send command
  #
  $REQUEST="COMMAND=$COMMAND AUTH=$AUTH";
  $ESCREQUEST=$REQUEST;
  $ESCREQUEST =~ s/"/\\"/g;     # Escape quotes in checksum
  chomp($CHECKSUM = `$QAUTH "$ESCREQUEST"`);
  $REQUEST .= " CHECKSUM=$CHECKSUM";
  my $command=pack "a8 a1 A*",sprintf("%08d",length($REQUEST))," ",$REQUEST;
  print S "$command";             # Send Command to server
  while (<S>) { push(@REPLY,$_); }        # Listen for Reply
  $reply=join("\n",@REPLY);
  $STATUS=$1 if $reply=~s/STATUSCODE=(\d*)//;
  $MESSAGE=$1 if $reply=~s/MESSAGE="(.*)"//;
  grep(s/.*RESULT=//,@REPLY);             # Parse out the RESULT
  return @REPLY;
}
